# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-12 19:03
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DiscordIntegration',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('bot_name', models.CharField(blank=True, help_text='Override the bot username set in the Discord settings.', max_length=30, verbose_name='discord bot username')),
                ('avatar_url', models.URLField(blank=True, help_text='Override the bot avatar set in the Discord settings', verbose_name='discord bot avatar')),
                ('webhook_url', models.URLField(help_text='The Discord webhook url found in the Discord settings', verbose_name='discord webhook url')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
